@@ -1,5 +1,6 @@
-import numpy as np # type: ignore
-import pandas as pd # type: ignore
+import numpy as np  # type: ignore
+import pandas as pd  # type: ignore
+from pandas import DatetimeIndex
 
 
 def dayofweek(df: pd.DataFrame) -> pd.DataFrame:
@@ -19,8 +20,9 @@ def dayofweek(df: pd.DataFrame) -> pd.DataFrame:
     dayofweek_mapping = {0: 1, 1: 2, 2: 3, 3: 4, 4: 5, 5: 6, 6: 0}
 
     # Create day of week as a new feature (for example: 0-sunday, 6-saturday)
-    df["dayofweek"] = df.index.dayofweek
-    df["dayofweek"] = df["dayofweek"].map(dayofweek_mapping)
-    df['dayofweek'] = df['dayofweek'].astype(np.float32)
+    initial_index: DatetimeIndex = df.index if isinstance(
+        df.index, DatetimeIndex) else pd.to_datetime(df.index)
+    df["dayofweek"] = initial_index.dayofweek.map(dayofweek_mapping).astype(
+        np.float32)
 
     return df
