@@ -1,5 +1,6 @@
-import numpy as np # type: ignore
-import pandas as pd # type: ignore
+import numpy as np  # type: ignore
+import pandas as pd  # type: ignore
+from pandas import DatetimeIndex
 
 
 def hourofday(df: pd.DataFrame) -> pd.DataFrame:
@@ -18,6 +19,7 @@ def hourofday(df: pd.DataFrame) -> pd.DataFrame:
     
     """
     # Create hours of day as a new feature (for example: 0-23)
-    df['hourofday'] = df.index.hour
-    df['hourofday'] = df['hourofday'].astype(np.float32)
+    initial_index: DatetimeIndex = df.index if isinstance(
+        df.index, DatetimeIndex) else pd.to_datetime(df.index)
+    df["hourofday"] = initial_index.hour.astype(np.float32)
     return df
